==> tota-0.4.0.tar.gz: lib/src/commands/new.dart <==
import 'package:args/command_runner.dart';
import 'package:cli_util/cli_logging.dart';
import 'package:dotenv/dotenv.dart' as dotenv;

import '../../tota.dart' as tota;
import '../config.dart';
import '../tota_exception.dart';

class NewCommand extends Command {
  final name = 'new';
  final description = 'Create a new page.';

  NewCommand() {
    argParser.addOption('type',
        allowed: ['page', 'post'],
        defaultsTo: 'pages',
        abbr: 't',
        help: 'Type of page to create.');
    argParser.addFlag('verbose',
        abbr: 'v', negatable: false, help: 'Enable verbose logging.');
    argParser.addFlag('force',
        abbr: 'f',
        negatable: false,
        help: 'Force creation of file.',
        defaultsTo: false);
  }

  /// Converts a page type [name] into a Tota resource type.
  tota.ResourceType getResourceType(String name) {
    switch (name) {
      case 'post':
        return tota.ResourceType.post;
      default:
        return tota.ResourceType.page;
    }
  }

  void run() async {
    dotenv.load();

    Logger logger =
        argResults['verbose'] ? Logger.verbose() : Logger.standard();

    try {
      Config config = tota.loadConfig();

      String title = argResults.rest.isEmpty ? '' : argResults.rest[0];
      if (title.isEmpty) {
        throw TotaException('Title is required');
      }

      await tota.createPage(getResourceType(argResults['type']), title,
          config: config, force: argResults['force'], logger: logger);

      logger.stdout('File ${logger.ansi.emphasized('created')}.');
    } catch (e) {
      logger.stderr(logger.ansi.error(e.message));
    }
  }
}

==> tota-0.5.0.tar.gz: lib/src/commands/new.dart <==
import 'package:args/command_runner.dart';
import 'package:cli_util/cli_logging.dart';
import 'package:dotenv/dotenv.dart' as dotenv;

import '../../tota.dart';
import '../config.dart';
import '../exceptions.dart';

class NewCommand extends Command {
  @override
  final name = 'new';

  @override
  final description = 'Create a new page.';

  NewCommand() {
    argParser.addOption('type',
        allowed: ['page', 'post'],
        defaultsTo: 'pages',
        abbr: 't',
        help: 'Type of page to create.');
    argParser.addFlag('verbose',
        abbr: 'v', negatable: false, help: 'Enable verbose logging.');
    argParser.addFlag('force',
        abbr: 'f',
        negatable: false,
        help: 'Force creation of file.',
        defaultsTo: false);
  }

  @override
  void run() async {
    dotenv.load();

    Logger logger =
        argResults['verbose'] ? Logger.verbose() : Logger.standard();

    try {
      Config config = Config.fromEnv();

      String title = argResults.rest.isEmpty ? '' : argResults.rest[0];
      if (title.isEmpty) {
        throw TotaException('Title is required');
      }

      await createPage(_parseResourceType(argResults['type']), title,
          config: config, force: argResults['force'], logger: logger);

      logger.stdout('File ${logger.ansi.emphasized('created')}.');
    } on TotaIOException catch (e) {
      logger.stderr(logger.ansi.error('${e.message}: ${e.path}'));
    } catch (e) {
      logger.stderr(logger.ansi.error(e.message));
    }
  }
}

/// Parses page [type] and returns a valid resource type.
ResourceType _parseResourceType(String type) {
  switch (type) {
    case 'post':
      return ResourceType.post;
    default:
      return ResourceType.page;
  }
}
